%global momorel 1

# skip tests known to be problematic in a specific version
%global skip_checks_version 0.1.10
# concurrency-stress-test: https://bugzilla.gnome.org/show_bug.cgi?id=673419
%global skip_checks concurrency-stress-test

%global develdocdir %{_docdir}/%{name}-devel/ht%global develdocdir %{_docdir}/%{name}-devel/htmlml

Summary: pixel format conversion library
Name: babl
Version: 0.1.56
Release: %{momorel}m%{?dist}

# Compute some version related macros
# Ugly hack, you need to get your quoting backslashes/percent signs straight
%global major %(ver=%version; echo ${ver%%%%.*})
%global minor %(ver=%version; ver=${ver#%major.}; echo ${ver%%%%.*})
%global micro %(ver=%version; ver=${ver#%major.%minor.}; echo ${ver%%%%.*})
%global apiver %major.%minor

License: LGPLv3+ and GPLv3+
Group: System Environment/Libraries
URL: http://www.gegl.org/babl/
Source0: http://download.gimp.org/pub/%{name}/%{apiver}/%{name}-%{version}.tar.bz2 
NoSource: 0
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:	librsvg2

%description
Babl is a dynamic, any to any, pixel format conversion library. It
provides conversions between the myriad of buffer types images can be
stored in. Babl doesn't only help with existing pixel formats, but
also facilitates creation of new and uncommon ones.
#'

%package devel
Summary: pixel format conversion library
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
This package contains the libraries and header files needed for
developing with %{name}.

%package devel-docs
Summary:	Documentation for developing programs that will use %{name}
Group:		Documentation
BuildArch:	noarch
Requires:	%{name}-devel = %{version}-%{release}
# Split off devel docs from 0.1.2-2 on
Obsoletes:	%{name}-devel < 0.1.2-2%{?dist}
Conflicts:	%{name}-devel < 0.1.2-2%{?dist}

%description devel-docs
This package contains documentation needed for developing with %{name}.

%prep
%setup -q

%build
# use PIC/PIE because babl is likely to deal with data coming from untrusted
# sources
CFLAGS="-fPIC %optflags -fno-strict-aliasing"
LDFLAGS="-pie"
%configure --disable-static

make V=1 %{?_smp_mflags}

%install
rm -rf --preserve-root %{buildroot}
make DESTDIR=%{buildroot} install INSTALL='install -p'

mkdir -p "%{buildroot}/%{develdocdir}"
cp -pr docs/graphics docs/*.html docs/babl.css "%{buildroot}/%{develdocdir}"
rm -rf "%{buildroot}/%{develdocdir}"/graphics/Makefile*

find %{buildroot} -type f -name "*.la" -exec rm -f {} ';'

%check
# skip tests known to be problematic in a specific version
%if "%version" == "%skip_checks_version"
pushd tests
for problematic in %skip_checks; do
    rm -f "$problematic"
    cat << EOF > "$problematic"
#!/bin/sh
echo Skipping test "$problematic"
EOF
    chmod +x "$problematic"
done
popd
%endif
make check

%clean
rm -rf --preserve-root %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING README NEWS
%{_libdir}/*.so.*
%{_libdir}/babl-%{apiver}/

%files devel
%defattr(-,root,root)
%{_includedir}/babl-%{apiver}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%files devel-docs
%defattr(-, root, root, -)
%doc %{develdocdir}

%changelog
* Mon Aug 20 2018 Yohsuke Ooi <meke@momonga-linux.org>
- (0.1.56-1m)
- update to 0.1.56

* Thu Jul 05 2018 Yohsuke Ooi <meke@momonga-linux.org>
- (0.1.52-1m)
- update to 0.1.52

* Wed May 23 2018 Yohsuke Ooi <meke@momonga-linux.org>
- (0.1.50-1m)
- update to 0.1.50

* Fri Feb 23 2018 Yohsuke Ooi <meke@momonga-linux.org>
- (0.1.44-1m)
- update to 0.1.44

* Sun Jan 07 2018 Yohsuke Ooi <meke@momonga-linux.org>
- (0.1.38-1m)
- update to 0.1.38

* Thu Jan 26 2017 Yohsuke Ooi <meke@momonga-linux.org>
- (0.1.22-1m)
- update to 0.1.22

* Mon Mar 28 2016 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (0.1.16-1m)
- update to 0.1.16

* Mon Jun 11 2012 SANUKI Masaru <sanuki@momonga-linux.org> 
- (0.1.10-1m)
- update to 0.1.10

* Tue Jan 10 2012 Yohsuke Ooi <meke@momonga-linux.org> 
- (0.1.6-1m)
- update to 0.1.6

* Mon Jul 18 2011 Nishio Futoshi <futoshi@momonga-linux.org>
- (0.1.4-1m)
- update to 0.1.4

* Mon Apr 11 2011 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (0.1.2-4m)
- rebuild for new GCC 4.6

* Sun Nov 28 2010 Hiromasa YOSHIMOTO <y@momonga-linux.org>
- (0.1.2-3m)
- rebuild for new GCC 4.5

* Tue Aug 31 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (0.1.2-2m)
- full rebuild for mo7 release

* Mon Apr 12 2010 Yohsuke Ooi <meke@momonga-linux.org>
- (0.1.2-1m)
- update 0.1.2

* Sat Nov 14 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (0.1.0-2m)
- rebuild against gcc-4.4 and glibc-2.11

* Thu Sep  3 2009 Yohsuke Ooi <meke@momonga-linux.org> 
- (0.1.0-1m)
- update 0.1.0

* Wed Jan 21 2009 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (0.0.22-2m)
- rebuild against rpm-4.6

* Fri Jul  4 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (0.0.22-1m)
- update 0.0.22

* Tue May 06 2008 Masayuki SANO <nosanosa@momonga-linux.org>
- (0.0.20-1m)
- update to 0.0.20

* Thu Apr 03 2008 TABUCHI Takaaki <tab@momonga-linux.org>
- (0.0.14-3m)
- rebuild against gcc43

* Wed Feb 13 2008 Yohsuke Ooi <meke@momonga-linux.org>
- (0.0.14-2m)
- %%NoSource -> NoSource

* Sun Sep 23 2007 Nishio Futoshi <futoshi@momonga-linux.org>
- (0.0.14-1m)
- initial build
